@@ -34,7 +34,7 @@
 #include <tqpaintdevice.h>
 #include <tqcolor.h>
 
-#include <kapp.h>
+#include <tdeapplication.h>
 
 
 
